from pathlib import Path
from typing import Dict, Set, Any
from datasets.arrow_dataset import Dataset

from experiment.dataset_helper import DatasetHelper
from sziszapangma.model.relation_manager import RelationManager, FileRelationManager


class HfRecordProvider(DatasetHelper):
    _path_by_id: Dict[str, str]
    _relation_manager_root_path: str
    _dataset: Dataset
    _id_tags_count: int

    def __init__(self, dataset: Dataset, relation_manager_root_path: str, id_tags_count: int = 1, path_prefix: str = ''):
        self._id_tags_count = id_tags_count
        print([it for it in dataset])
        self._path_by_id = dict({
            self.get_id_from_record(it): path_prefix + it['path']
            for it in dataset
        })
        self._dataset = dataset
        self._relation_manager_root_path = relation_manager_root_path

    def get_all_records(self) -> Set[str]:
        return set(self._path_by_id.keys())

    def get_path(self, record_id: str) -> str:
        return self._path_by_id[record_id]

    def get_relation_manager(self, record_id: str) -> RelationManager:
        record_path = Path(self._relation_manager_root_path).joinpath(record_id)
        record_path.mkdir(parents=True, exist_ok=True)
        return FileRelationManager(
            str(record_path.joinpath('ab_relations.csv')),
            str(record_path.joinpath('ab_items.json'))
        )

    def get_dataset(self) -> Dataset:
        return self._dataset

    def get_id_from_record(self, record: Dict[str, Any]) -> str:
        path = record['path']
        return '__'.join(path.split('/')[-self._id_tags_count:])
